==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxTextChangedEventArgsDescription } from "./MultiColumnComboBoxTextChangedEventArgsDescription";
/**
 * @hidden
 */
export let MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a == null) {
                MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.b(a);
            a.aa("MultiColumnComboBoxTextChangedEventArgs", () => new MultiColumnComboBoxTextChangedEventArgsDescription());
            a.z("MultiColumnComboBoxTextChangedEventArgs", MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
        }
    }
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxTextChangedEventArgsDescription } from "./MultiColumnComboBoxTextChangedEventArgsDescription";
/**
 * @hidden
 */
export let MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a == null) {
                MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.b(a);
            a.ac("MultiColumnComboBoxTextChangedEventArgs", () => new MultiColumnComboBoxTextChangedEventArgsDescription());
            a.ab("MultiColumnComboBoxTextChangedEventArgs", MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
        }
    }
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata;
})();
